==> libreoffice-5.3.7.2.tar.xz: libreoffice-5.3.7.2/sw/source/core/docnode/pausethreadstarting.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <pausethreadstarting.hxx>
#include <swthreadmanager.hxx>

/* Helper class to pause starting of threads during existence of an instance
    of this class

    #i73788#
*/

SwPauseThreadStarting::SwPauseThreadStarting()
    : mbPausedThreadStarting( false )
{
    if ( SwThreadManager::ExistsThreadManager() &&
         !SwThreadManager::GetThreadManager().StartingOfThreadsSuspended() )
    {
        SwThreadManager::GetThreadManager().SuspendStartingOfThreads();
        mbPausedThreadStarting = true;
    }
}

SwPauseThreadStarting::~SwPauseThreadStarting()
{
    if ( mbPausedThreadStarting )
    {
        SwThreadManager::GetThreadManager().ResumeStartingOfThreads();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-6.4.1.2.tar.xz: libreoffice-6.4.1.2/sw/source/core/docnode/pausethreadstarting.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <pausethreadstarting.hxx>
#include <swthreadmanager.hxx>

/* Helper class to pause starting of threads during existence of an instance
    of this class

    #i73788#
*/

SwPauseThreadStarting::SwPauseThreadStarting()
    : mbPausedThreadStarting( false )
{
    if ( SwThreadManager::ExistsThreadManager() &&
         !SwThreadManager::GetThreadManager().StartingOfThreadsSuspended() )
    {
        SwThreadManager::GetThreadManager().SuspendStartingOfThreads();
        mbPausedThreadStarting = true;
    }
}

SwPauseThreadStarting::~SwPauseThreadStarting() COVERITY_NOEXCEPT_FALSE
{
    if ( mbPausedThreadStarting )
    {
        SwThreadManager::GetThreadManager().ResumeStartingOfThreads();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
